@@ -185,21 +185,22 @@ item_table = [
     {
         "count": 1,
         "name": "Family Sedan",
-        "category": ["Level 1 Cars", "Cars"],
-        "progression": True,
+        "category": ["Level 1 Cars", "Cars", "Small Cars"],
+        "progression": False,
+        "useful": True,
         "id": 121810
     },
     {
         "count": 1,
         "name": "Plow King",
-        "category": ["Progression", "Level 1 Cars", "Cars"],
+        "category": ["Progression", "Level 1 Cars", "Cars", "Large Cars"],
         "progression": True,
         "id": 121811
     },
     {
         "count": 1,
         "name": "Duff Truck",
-        "category": ["Cars", "Level 1 Cars"],
+        "category": ["Cars", "Level 1 Cars", "Large Cars"],
         "useful": True,
         "id": 121812,
         "progression": False
@@ -207,7 +208,7 @@ item_table = [
     {
         "count": 1,
         "name": "Surveillance Van",
-        "category": ["Cars", "Level 1 Cars"],
+        "category": ["Cars", "Level 1 Cars", "Medium Cars"],
         "useful": True,
         "id": 121813,
         "progression": False
@@ -215,7 +216,7 @@ item_table = [
     {
         "count": 1,
         "name": "Pickup Truck",
-        "category": ["Cars", "Level 1 Cars"],
+        "category": ["Cars", "Level 1 Cars", "Medium Cars"],
         "useful": True,
         "id": 121814,
         "progression": False
@@ -223,7 +224,7 @@ item_table = [
     {
         "count": 1,
         "name": "Electaurus",
-        "category": ["Cars", "Level 1 Cars"],
+        "category": ["Cars", "Level 1 Cars", "Small Cars"],
         "useful": True,
         "id": 121815,
         "progression": False
@@ -231,14 +232,14 @@ item_table = [
     {
         "count": 1,
         "name": "Mr. Plow",
-        "category": ["Progression", "Level 2 Cars", "Cars"],
+        "category": ["Progression", "Level 2 Cars", "Cars", "Medium Cars"],
         "progression": True,
         "id": 121816
     },
     {
         "count": 1,
         "name": "Limo",
-        "category": ["Cars", "Level 2 Cars"],
+        "category": ["Cars", "Level 2 Cars", "Small Cars"],
         "useful": True,
         "id": 121817,
         "progression": False
@@ -246,7 +247,7 @@ item_table = [
     {
         "count": 1,
         "name": "Fire Truck",
-        "category": ["Cars", "Level 2 Cars"],
+        "category": ["Cars", "Level 2 Cars", "Large Cars"],
         "useful": True,
         "id": 121818,
         "progression": False
@@ -254,7 +255,7 @@ item_table = [
     {
         "count": 1,
         "name": "WWII Vehicle",
-        "category": ["Cars", "Level 2 Cars"],
+        "category": ["Cars", "Level 2 Cars", "Medium Cars"],
         "useful": True,
         "id": 121819,
         "progression": False
@@ -262,7 +263,7 @@ item_table = [
     {
         "count": 1,
         "name": "Moe's Sedan",
-        "category": ["Cars", "Level 2 Cars"],
+        "category": ["Cars", "Level 2 Cars", "Small Cars"],
         "useful": True,
         "id": 121820,
         "progression": False
@@ -270,14 +271,14 @@ item_table = [
     {
         "count": 1,
         "name": "School Bus",
-        "category": ["Progression", "Level 3 Cars"],
+        "category": ["Progression", "Level 3 Cars", "Large Cars"],
         "progression": True,
         "id": 121821
     },
     {
         "count": 1,
         "name": "Donut Truck",
-        "category": ["Cars", "Level 3 Cars"],
+        "category": ["Cars", "Level 3 Cars", "Medium Cars"],
         "useful": True,
         "id": 121822,
         "progression": False
@@ -285,7 +286,7 @@ item_table = [
     {
         "count": 1,
         "name": "Nerd Car",
-        "category": ["Cars", "Level 3 Cars"],
+        "category": ["Cars", "Level 3 Cars", "Small Cars"],
         "useful": True,
         "id": 121823,
         "progression": False
@@ -293,7 +294,7 @@ item_table = [
     {
         "count": 1,
         "name": "Skinner's Sedan",
-        "category": ["Cars", "Level 3 Cars"],
+        "category": ["Cars", "Level 3 Cars", "Medium Cars"],
         "useful": True,
         "id": 121824,
         "progression": False
@@ -301,7 +302,7 @@ item_table = [
     {
         "count": 1,
         "name": "Book Burning Van",
-        "category": ["Cars", "Level 3 Cars"],
+        "category": ["Cars", "Level 3 Cars", "Medium Cars"],
         "useful": True,
         "id": 121825,
         "progression": False
@@ -309,7 +310,7 @@ item_table = [
     {
         "count": 1,
         "name": "Tractor",
-        "category": ["Cars", "Level 4 Cars"],
+        "category": ["Cars", "Level 4 Cars", "Medium Cars"],
         "useful": True,
         "id": 121826,
         "progression": False
@@ -317,7 +318,7 @@ item_table = [
     {
         "count": 1,
         "name": "Curator",
-        "category": ["Cars", "Level 4 Cars"],
+        "category": ["Cars", "Level 4 Cars", "Small Cars"],
         "useful": True,
         "id": 121827,
         "progression": False
@@ -325,7 +326,7 @@ item_table = [
     {
         "count": 1,
         "name": "Krusty's Limo",
-        "category": ["Cars", "Level 4 Cars"],
+        "category": ["Cars", "Level 4 Cars", "Small Cars"],
         "useful": True,
         "id": 121828,
         "progression": False
@@ -333,7 +334,7 @@ item_table = [
     {
         "count": 1,
         "name": "Kremlin",
-        "category": ["Cars", "Level 4 Cars"],
+        "category": ["Cars", "Level 4 Cars", "Small Cars"],
         "useful": True,
         "id": 121829,
         "progression": False
@@ -341,7 +342,7 @@ item_table = [
     {
         "count": 1,
         "name": "Clown Car",
-        "category": ["Cars", "Level 4 Cars"],
+        "category": ["Cars", "Level 4 Cars", "Small Cars"],
         "useful": True,
         "id": 121830,
         "progression": False
@@ -349,14 +350,14 @@ item_table = [
     {
         "count": 1,
         "name": "Car Built For Homer",
-        "category": ["Progression", "Level 5 Cars"],
+        "category": ["Progression", "Level 5 Cars", "Small Cars"],
         "progression": True,
         "id": 121831
     },
     {
         "count": 1,
         "name": "Cola Truck",
-        "category": ["Cars", "Level 5 Cars"],
+        "category": ["Cars", "Level 5 Cars", "Large Cars"],
         "useful": True,
         "id": 121832,
         "progression": False
@@ -364,7 +365,7 @@ item_table = [
     {
         "count": 1,
         "name": "Police Car",
-        "category": ["Cars", "Level 5 Cars"],
+        "category": ["Cars", "Level 5 Cars", "Small Cars"],
         "useful": True,
         "id": 121833,
         "progression": False
@@ -372,7 +373,7 @@ item_table = [
     {
         "count": 1,
         "name": "Hover Car",
-        "category": ["Cars", "Level 5 Cars"],
+        "category": ["Cars", "Level 5 Cars", "Small Cars"],
         "useful": True,
         "id": 121834,
         "progression": False
@@ -380,7 +381,7 @@ item_table = [
     {
         "count": 1,
         "name": "El Carro Loco",
-        "category": ["Cars", "Level 5 Cars"],
+        "category": ["Cars", "Level 5 Cars", "Small Cars"],
         "useful": True,
         "id": 121835,
         "progression": False
@@ -388,14 +389,14 @@ item_table = [
     {
         "count": 1,
         "name": "Globex Super Villain Car",
-        "category": ["Progression", "Level 6 Cars", "Cars"],
+        "category": ["Progression", "Level 6 Cars", "Cars", "Small Cars"],
         "progression": True,
         "id": 121836
     },
     {
         "count": 1,
         "name": "Armored Truck",
-        "category": ["Cars", "Level 6 Cars"],
+        "category": ["Cars", "Level 6 Cars", "Large Cars"],
         "useful": True,
         "id": 121837,
         "progression": False
@@ -403,7 +404,7 @@ item_table = [
     {
         "count": 1,
         "name": "Chase Sedan",
-        "category": ["Cars", "Level 6 Cars"],
+        "category": ["Cars", "Level 6 Cars", "Small Cars"],
         "useful": True,
         "id": 121838,
         "progression": False
@@ -411,7 +412,7 @@ item_table = [
     {
         "count": 1,
         "name": "Bandit",
-        "category": ["Cars", "Level 6 Cars"],
+        "category": ["Cars", "Level 6 Cars", "Small Cars"],
         "useful": True,
         "id": 121839,
         "progression": False
@@ -419,7 +420,7 @@ item_table = [
     {
         "count": 1,
         "name": "36 Stutz Bearcat",
-        "category": ["Cars", "Level 6 Cars"],
+        "category": ["Cars", "Level 6 Cars", "Small Cars"],
         "useful": True,
         "id": 121840,
         "progression": False
@@ -427,14 +428,14 @@ item_table = [
     {
         "count": 1,
         "name": "Zombie Car",
-        "category": ["Progression", "Level 7 Cars", "Cars"],
+        "category": ["Progression", "Level 7 Cars", "Cars", "Small Cars"],
         "progression": True,
         "id": 121841
     },
     {
         "count": 1,
         "name": "Hearse",
-        "category": ["Cars", "Level 7 Cars"],
+        "category": ["Cars", "Level 7 Cars", "Small Cars"],
         "useful": True,
         "id": 121842,
         "progression": False
@@ -442,7 +443,7 @@ item_table = [
     {
         "count": 1,
         "name": "Mr. Burns' Limo",
-        "category": ["Cars", "Level 7 Cars"],
+        "category": ["Cars", "Level 7 Cars", "Medium Cars"],
         "useful": True,
         "id": 121843,
         "progression": False
@@ -450,7 +451,7 @@ item_table = [
     {
         "count": 1,
         "name": "Hover Bike",
-        "category": ["Cars", "Level 7 Cars"],
+        "category": ["Cars", "Level 7 Cars", "Small Cars"],
         "useful": True,
         "id": 121844,
         "progression": False
@@ -458,7 +459,7 @@ item_table = [
     {
         "count": 1,
         "name": "Open Wheel Race Car",
-        "category": ["Cars", "Level 7 Cars"],
+        "category": ["Cars", "Level 7 Cars", "Small Cars"],
         "useful": True,
         "id": 121845,
         "progression": False
@@ -466,43 +467,49 @@ item_table = [
     {
         "count": 1,
         "name": "Honor Roller",
-        "category": ["Cars", "Level 2 Cars"],
-        "progression": True,
+        "category": ["Cars", "Level 2 Cars", "Small Cars"],
+        "progression": False,
+        "useful": True,
         "id": 121846
     },
     {
         "count": 1,
         "name": "Malibu Stacy Car",
-        "category": ["Cars", "Level 3 Cars"],
-        "progression": True,
+        "category": ["Cars", "Level 3 Cars", "Small Cars"],
+        "progression": False,
+        "useful": True,
         "id": 121847
     },
     {
         "count": 1,
         "name": "Canyonero",
-        "category": ["Cars", "Level 4 Cars"],
-        "progression": True,
+        "category": ["Cars", "Level 4 Cars", "Medium Cars"],
+        "progression": False,
+        "useful": True,
         "id": 121848
     },
     {
         "count": 1,
         "name": "Longhorn",
-        "category": ["Cars", "Level 5 Cars"],
-        "progression": True,
+        "category": ["Cars", "Level 5 Cars", "Small Cars"],
+        "progression": False,
+        "useful": True,
         "id": 121849
     },
     {
         "count": 1,
         "name": "Ferrini - Red",
-        "category": ["Cars", "Level 6 Cars"],
-        "progression": True,
+        "category": ["Cars", "Level 6 Cars", "Small Cars"],
+        "progression": False,
+        "useful": True,
         "id": 121850
     },
     {
         "count": 1,
         "name": "70's Sports Car",
-        "category": ["Cars", "Level 7 Cars"],
-        "progression": True,
+        "category": ["Cars", "Level 7 Cars", "Small Cars"],
+        "progression": False,
+        "useful": True,
         "id": 121851
     },
     {
@@ -735,7 +742,7 @@ item_table = [
         "name": "Apu Gagfinder",
         "category": ["Gags"],
         "progression": True,
-        "id": 121899 #highest id
+        "id": 121899
     },
     {
         "count": 50,
@@ -746,14 +753,14 @@ item_table = [
         "progression": False
     },
     {
-        "count": 50,
+        "count": 40,
         "name": "Hit N Run Reset",
         "category": ["Filler"],
         "id": 121876,
         "progression": False
     },
     {
-        "count": 100,
+        "count": 30,
         "name": "10 Coins",
         "category": ["Filler"],
         "id": 121877,
@@ -786,7 +793,7 @@ item_table = [
     {
         "count": 1,
         "name": "Speed Rocket",
-        "category": ["Cars", "Level 1 Cars"],
+        "category": ["Cars", "Level 1 Cars", "Small Cars"],
         "useful": True,
         "id": 121880,
         "progression": False
@@ -794,7 +801,7 @@ item_table = [
     {
         "count": 1,
         "name": "Monorail Car",
-        "category": ["Cars", "Level 2 Cars"],
+        "category": ["Cars", "Level 2 Cars", "Medium Cars"],
         "useful": True,
         "id": 121881,
         "progression": False
@@ -802,7 +809,7 @@ item_table = [
     {
         "count": 1,
         "name": "Knight Boat",
-        "category": ["Cars", "Level 3 Cars"],
+        "category": ["Cars", "Level 3 Cars", "Small Cars"],
         "useful": True,
         "id": 121882,
         "progression": False
@@ -810,7 +817,7 @@ item_table = [
     {
         "count": 1,
         "name": "ATV",
-        "category": ["Cars", "Level 4 Cars"],
+        "category": ["Cars", "Level 4 Cars", "Small Cars"],
         "useful": True,
         "id": 121883,
         "progression": False
@@ -818,7 +825,7 @@ item_table = [
     {
         "count": 1,
         "name": "Obliteratatron Big Wheel Truck",
-        "category": ["Cars", "Level 5 Cars"],
+        "category": ["Cars", "Level 5 Cars", "Extra Large Cars"],
         "useful": True,
         "id": 121884,
         "progression": False
@@ -826,7 +833,7 @@ item_table = [
     {
         "count": 1,
         "name": "Planet Hype 50's Car",
-        "category": ["Cars", "Level 6 Cars"],
+        "category": ["Cars", "Level 6 Cars", "Small Cars"],
         "useful": True,
         "id": 121885,
         "progression": False
@@ -834,7 +841,7 @@ item_table = [
     {
         "count": 1,
         "name": "R/C Buggy",
-        "category": ["Cars", "Level 1 Cars"],
+        "category": ["Cars", "Level 1 Cars", "Extra Small Cars"],
         "useful": True,
         "id": 121886,
         "progression": False
@@ -853,6 +860,317 @@ item_table = [
         "id": 121888,
         "progression": True
     },
+    {
+        "count": 1,
+        "name": "Mini School Bus",
+        "category": ["Cars", "Traffic", "Filler", "Level 1 Cars", "Large Cars"],
+        "id": 121900,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Glass Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level 1 Cars", "Medium Cars"],
+        "id": 121901,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Minivan",
+        "category": ["Cars", "Traffic", "Filler", "Level 1 Cars", "Medium Cars"],
+        "id": 121902,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Pizza Van",
+        "category": ["Cars", "Traffic", "Filler", "Level 2 Cars", "Medium Cars"],
+        "id": 121903,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Taxi",
+        "category": ["Cars", "Traffic", "Filler", "Level 2 Cars", "Small Cars"],
+        "id": 121904,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Sedan B",
+        "category": ["Cars", "Traffic", "Filler", "Level 2 Cars", "Small Cars"],
+        "id": 121905,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Fish Van",
+        "category": ["Cars", "Traffic", "Filler", "Level 3 Cars", "Medium Cars"],
+        "id": 121906,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Garbage Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level 4 Cars", "Large Cars"],
+        "id": 121907,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Nuclear Waste Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level 4 Cars", "Medium Cars"],
+        "id": 121908,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Vote Quimby Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level 5 Cars", "Large Cars"],
+        "id": 121934,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Ambulance",
+        "category": ["Cars", "Traffic", "Filler", "Level 5 Cars", "Large Cars"],
+        "id": 121935,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Sports Car B",
+        "category": ["Cars", "Traffic", "Filler", "Level 2 Cars", "Level 5 Cars", "Small Cars"],
+        "id": 121936,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Itchy and Scratchy Movie Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level 6 Cars", "Large Cars"],
+        "id": 121937,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Burns Armored Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level 6 Cars", "Large Cars"],
+        "id": 121938,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Pickup",
+        "category": ["Cars", "Traffic", "Filler", "Level 1 Cars", "Level 3 Cars", "Level 6 Cars", "Medium Cars"],
+        "id": 121909,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Sports Car A",
+        "category": ["Cars", "Traffic", "Filler", "Level 3 Cars", "Small Cars"],
+        "id": 121910,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Compact Car",
+        "category": ["Cars", "Traffic", "Filler", "Level 3 Cars", "Level 4 Cars", "Level 6 Cars", "Small Cars"],
+        "id": 121911,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "SUV",
+        "category": ["Cars", "Traffic", "Filler", "Level 4 Cars", "Level 5 Cars", "Small Cars"],
+        "id": 121912,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Hallo Hearse",
+        "category": ["Cars", "Traffic", "Filler", "Level 7 Cars", "Small Cars"],
+        "id": 121913,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Coffin Car",
+        "category": ["Cars", "Traffic", "Filler", "Level 7 Cars", "Small Cars"],
+        "id": 121914,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Ghost Ship",
+        "category": ["Cars", "Traffic", "Filler", "Level 7 Cars", "Small Cars"],
+        "id": 121915,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Witch's Broom",
+        "category": ["Cars", "Traffic", "Filler", "Level 7 Cars", "Small Cars"],
+        "id": 121916,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Sedan A",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Small Cars"],
+        "id": 121917,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Station Wagon",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Small Cars"],
+        "id": 121918,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Ice Cream Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Large Cars"],
+        "id": 121919,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Bonestorm Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Large Cars"],
+        "id": 121920,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Cell Phone Car",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Small Cars"],
+        "id": 121921,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Milk Truck",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Large Cars"],
+        "id": 121922,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Nonuplets Minivan",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Medium Cars"],
+        "id": 121923,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Ferrini - Black",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Small Cars"],
+        "id": 121924,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Homer Frink-o-Matic Wasp Bumper",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121925
+    },
+    {
+        "count": 1,
+        "name": "Bart Frink-o-Matic Wasp Bumper",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121926
+    },
+    {
+        "count": 1,
+        "name": "Lisa Frink-o-Matic Wasp Bumper",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121927
+    },
+    {
+        "count": 1,
+        "name": "Marge Frink-o-Matic Wasp Bumper",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121928
+    },
+    {
+        "count": 1,
+        "name": "Apu Frink-o-Matic Wasp Bumper",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121929
+    },
+    {
+        "count": 20,
+        "name": "Traffic Trap",
+        "category": ["Filler"],
+        "trap": True,
+        "id": 121930,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Cube Van",
+        "category": ["Cars", "Traffic", "Filler", "Level Any Cars", "Large Cars"],
+        "id": 121931,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "WWII Vehicle W/ Rocket",
+        "category": ["Cars", "Level 7 Cars", "Medium Cars"],
+        "useful": True,
+        "id": 121932,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Audi TT",
+        "category": ["Cars", "Level Any Cars", "Small Cars"],
+        "useful": True,
+        "id": 121933,
+        "progression": False
+    },
+    {
+        "count": 1,
+        "name": "Homer Forward",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121938
+    },
+    {
+        "count": 1,
+        "name": "Bart Forward",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121939
+    },
+    {
+        "count": 1,
+        "name": "Lisa Forward",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121940
+    },
+    {
+        "count": 1,
+        "name": "Marge Forward",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121941
+    },
+    {
+        "count": 1,
+        "name": "Apu Forward",
+        "category": ["Moves"],
+        "progression": True,
+        "id": 121942 #highest id
+    },
 ]
 
 for item in item_table:
