@@ -1,5 +1,7 @@
 from dataclasses import dataclass
-from Options import (Toggle, Choice, Range, PerGameCommonOptions, DeathLink)
+from Options import (Toggle, Choice, Range, OptionSet, PerGameCommonOptions, DeathLink)
+
+VALID_CHAR_KEYS = ["Homer", "Bart", "Lisa", "Marge", "Apu", "All", "None"]
 
 class FillerTrapPercent(Range):
     """How many fillers will be replaced with traps. 0 means no additional traps, 100 means all fillers are traps."""
@@ -32,51 +34,85 @@ class LevelSanity(Choice):
     option_levels = 1
     default = 1
 
-class MoveRando(Toggle):
-    """Choose whether or not to shuffle moves into the item pool.
-       Moves that are shuffled are Double Jump and Attack for each character.
-       These have logical implications for wasp and card collection
-       as well as L7M4 requiring Homer Double Jump.
-       """
-
+class ShuffleStartingCar(Toggle):
+    """Choose whether to shuffle starting car between available cars from your starting level.
+       If disabled, you'll always start with your starting level's default car.
+        """
+    display_name = "Shuffle Starting Car"
     default = True
-    display_name = "Move Randomizer"
+
+class ShuffleAttack(OptionSet):
+    """Choose whether to add Attack to the pool for each character.
+       Valid options are Homer, Bart, Lisa, Marge, Apu, All, or None.
+    """
+
+    default = frozenset({"All"})
+    valid_keys = VALID_CHAR_KEYS
+    display_name = "Shuffle Attack"
+
+class ShuffleJump(OptionSet):
+    """Choose whether to add Jump to the pool for each character.
+       Valid options are Homer, Bart, Lisa, Marge, Apu, All, or None.
+    """
+
+    default = frozenset({"All"})
+    valid_keys = VALID_CHAR_KEYS
+    display_name = "Shuffle Jump"
 
 class StartingJumpLevel(Range):
     """Choose how many Progressive Jump items to start with for each character.
-       This option is always 2 if MoveRando is False. CARD LOGIC IS CURRENTLY INCORRECT
-       IF STARTING WITH 0 JUMPS"""
+       Characters who aren't included in ShuffleJump will start with Progressive Jump Level 2.
+    """
     display_name = "Starting Jump Level"
     range_start = 0
     range_end = 2
     default = 1
 
-class ShuffleGagfinder(Toggle):
-    """If enabled, add a Gagfinder to the pool for each Character that will be
-       required to unlock gags as that character. If disabled, gags will instead
-       be locked until you receive their Level.
+class ShuffleGagfinder(OptionSet):
+    """Choose whether to add a Gagfinder to the pool for each Character that will be required to
+       unlock gags as that character. Valid options are Homer, Bart, Lisa, Marge, Apu, All, or None.
+       If None, gags will instead be locked until you receive their Level.
        """
 
-    default = True
+    default = frozenset({"All"})
+    valid_keys = VALID_CHAR_KEYS
     display_name = "Shuffle Gagfinder"
 
-class ShuffleCheckeredFlags(Toggle):
-    """If enabled, add a Checkered Flag to the pool for each Character that will be
-       required to unlock races as that character. If disabled, races will instead
-       be locked until you receive their Level.
+class ShuffleCheckeredFlags(OptionSet):
+    """Choose whether to add a Checkered Flag to the pool for each Character that will be required to
+       unlock races as that character. Valid options are Homer, Bart, Lisa, Marge, Apu, All, or None.
+       If None, races will instead be locked until you receive their Level.
        """
 
-    default = True
+    default = frozenset({"All"})
+    valid_keys = VALID_CHAR_KEYS
     display_name = "Shuffle Checkered Flags"
 
-class ShuffleEBrakes(Toggle):
-    """Choose whether to shuffle ability to use the E-Brake
-       for each character into the item pool. *WARNING* This is not
-       considered in logic and has not been heavily tested.
-       It may create unreasonably hard seeds.
+class ShuffleForward(OptionSet):
+    """Choose whether to shuffle the ability to move forward or drive forward for each character into the item pool.
+       Valid options are Homer, Bart, Lisa, Marge, Apu, All, or None.
+       **THIS COULD CREATE VERY DIFFICULT SEEDS**
+    """
+
+    default = frozenset({"None"})
+    valid_keys = VALID_CHAR_KEYS
+    display_name = "Shuffle Forward"
+
+class EarlyForward(OptionSet):
+    """If enabled and forward is shuffled, try to place each specified character's Forward item early.
+       Valid options are Homer, Bart, Lisa, Marge, Apu, All, or None. Does nothing if the character's forward isn't shuffled.
+    """
+
+    default = frozenset({"All"})
+    valid_keys = VALID_CHAR_KEYS
+    display_name = "Early Forward"
+
+class ShuffleEBrakes(OptionSet):
+    """Choose whether to shuffle ability to use the E-Brake for each character into the item pool.
        """
 
-    default = True
+    default = frozenset({"All"})
+    valid_keys = VALID_CHAR_KEYS
     display_name = "Shuffle E-Brake"
 
 class EnableWaspPercent(Toggle):
@@ -117,20 +153,41 @@ class ShuffleCards(Toggle):
     display_name = "Shuffle Cards"
 
 class CardLogic(Choice):
-    """Choose logic level for cards and wasps.
+    """Choose logic level for cards.
        Carless: Cars are not considered at all in this logic level and cards that cannot be reached without them
                 are not available locations for ShuffleCards.
                 Note that the card on Level 6 that requires the Itchy and Scratchy Truck will still require it if ShuffleCards is false.
        Cars: Cars are considered in whether you can reach a card.
        Glitched: Glitches and speedrunning tricks are considered in whether you can reach a card.
-       ***CURRENTLY ONLY CARLESS LOGIC LEVEL IS SUPPORTED, OTHER OPTIONS WILL RAISE AN ERROR AND FAIL GENERATION"""
+       ***CURRENTLY GLITCHED LOGIC LEVEL IS NOT SUPPORTED AND WILL RAISE AN ERROR AND FAIL GENERATION"""
 
-    display_name = "Card and Wasp Logic"
+    display_name = "Card Logic"
     option_carless = 0
     option_cars = 1
     option_glitched = 2
     default = 0
 
+class WaspLogic(Choice):
+    """Choose logic level for wasps.
+       Strict: Wasps cannot be broken with cars and logically require Attack items.
+       Unlockable: Adds a "Frink-o-Matic Wasp Bumper" item for each character that allows them to break wasps with cars.
+                   Wasps logically require the bumper and a car that can reach them or Attack items.
+       Cars: Wasps logically require a car that can reach them or Attack items.
+       Open: Wasps logically require Attack items but can be broken with cars."""
+
+    display_name = "Wasp Logic"
+    option_strict = 0
+    option_unlockable = 1
+    option_cars = 2
+    option_open = 3
+
+class AddMissionLocks(Range):
+    """Add car requirements to a percentage of missions"""
+
+    display_name = "Mission Locks"
+    range_start = 0
+    range_end = 100
+
 class MinShopPrice(Range):
     """The minimum cost of any item in Gil's Shop. If this is greater than the max shop price, then the max will be used instead."""
     display_name = "Min Shop Price"
@@ -145,15 +202,6 @@ class MaxShopPrice(Range):
     range_end = 500
     default = 300
 
-class ShopHintPolicy(Choice):
-    """Choose the level of hints sent when speaking to Gil for the first time on a level
-       All: Hint all items in Gil's shop
-       OnlyProg: Only hint progression items in Gil's shop
-    """
-    display_name = "Shop Hint Policy"
-    option_all = 0
-    option_onlyprog = 1
-
 class ShopScaleMod(Range):
     """The multiplier for shop costs per levels
        L2 costs = L1 * multiplier, L3 = L1 * 2(multiplier), etc"""
@@ -162,6 +210,27 @@ class ShopScaleMod(Range):
     range_end = 5
     default = 2
 
+class ShopHintPolicy(Choice):
+    """Choose the level of hints sent when speaking to Gil for the first time on a level
+       All: Hint all items in Gil's shop
+       OnlyProg: Only hint progression items in Gil's shop
+       None: No shop hints will be created
+    """
+    display_name = "Shop Hint Policy"
+    option_all = 0
+    option_onlyprog = 1
+    option_none = 2
+
+class ExtraHintPolicy(Toggle):
+    """Place extra hints in various places."""
+    default = True
+    display_name = "Extra Hint Policy"
+
+class ShuffleTraffic(Toggle):
+    """Randomize traffic per level"""
+    default = True
+    display_name = "Shuffle Traffic"
+
 class EjectTraps(Toggle):
     """Whether to include Eject traps in the item pool."""
     default = True
@@ -182,30 +251,44 @@ class HNRTraps(Toggle):
     default = True
     display_name = "Enable Hit N Run Traps"
 
+class TrafficTraps(Toggle):
+    """Whether to include Traffic traps in the item pool."""
+    default = True
+    display_name = "Enable Traffic Traps"
+
 @dataclass
 class SimpsonsHitAndRunOptions(PerGameCommonOptions):
     goal: Goal
     levelsanity: LevelSanity
-    moverandomizer: MoveRando
+    startingcarshuffle: ShuffleStartingCar
+    shuffleattack: ShuffleAttack
+    shufflejump: ShuffleJump
     startjumplevel: StartingJumpLevel
     shufflegagfinder: ShuffleGagfinder
     shufflecheckeredflags: ShuffleCheckeredFlags
     shuffleebrake: ShuffleEBrakes
+    shuffleforward: ShuffleForward
+    earlyforward: EarlyForward
     EnableWaspPercent: EnableWaspPercent
     wasppercent: WaspPercent
     EnableCardPercent: EnableCardPercent
     cardpercent: CardPercent
     shufflecards: ShuffleCards
     cardlogic: CardLogic
+    wasplogic: WaspLogic
+    missionlocks: AddMissionLocks
     minprice: MinShopPrice
     maxprice: MaxShopPrice
     shopscalemod: ShopScaleMod
     shophintpolicy: ShopHintPolicy
+    extrahintpolicy: ExtraHintPolicy
+    shuffletraffic: ShuffleTraffic
     filler_traps: FillerTrapPercent
     eject: EjectTraps
     duff: DuffTraps
     launch: LaunchTraps
     hnr: HNRTraps
+    traffictrap: TrafficTraps
 
 
 SimpsonsHitAndRunOptions = SimpsonsHitAndRunOptions
