@@ -3,11 +3,18 @@ import logging
 import os
 import json
 import pkgutil
+import re
+from typing import Any, Dict, TextIO
+from pathlib import Path
 from typing import Callable, Optional
+from Options import OptionError
+import asyncio
+import typing
+import settings
 
 import Utils
 from worlds.generic.Rules import forbid_items_for_player
-from worlds.LauncherComponents import Component, SuffixIdentifier, components, Type, launch_subprocess
+from worlds.LauncherComponents import Component, SuffixIdentifier, components, Type, launch_subprocess, icon_paths
 
 from .Data import region_table, category_table, meta_table
 from .Meta import world_description, world_webworld, enable_region_diagram
@@ -32,11 +39,68 @@ from .hooks.World import \
     before_create_item, after_create_item, \
     before_set_rules, after_set_rules, \
     before_generate_basic, after_generate_basic, \
-    before_fill_slot_data, after_fill_slot_data, before_write_spoiler, card_table
+    before_fill_slot_data, after_fill_slot_data, before_write_spoiler
 from .hooks.Data import hook_interpret_slot_data
 
 from .SHARContainer import gen
 
+def get_options():
+    return SimpsonsHitAndRunOptions
+
+def get_world():
+    return SimpsonsHitAndRunWorld
+
+def _launch_shar_client_process():
+    import os, sys, subprocess
+    client_path = os.path.join(os.path.dirname(__file__), "SHARClient.py")
+    subprocess.Popen([sys.executable, client_path])
+
+async def run_client_async(ap_url=None):
+    from .SHARClient import SHARContext
+    ctx = SHARContext()  # lightweight constructor
+    await ctx.initialize()  # tasks can be scheduled safely
+    if ap_url:
+        await ctx.handle_apshar(Path(ap_url))
+    else:
+        await ctx.start()
+
+def run_client(ap_url=None):
+    asyncio.run(run_client_async(ap_url))
+
+
+
+# ---- Component Registration ----
+components.append(
+    Component(
+        "Simpsons Hit & Run Client",
+        func=run_client,
+        component_type=Type.CLIENT,
+        file_identifier=SuffixIdentifier(".apshar"),
+        cli=True,
+        icon="Donut"
+    )
+)
+
+icon_paths["Donut"] = f"ap:{__name__}/icons/Donut.png"
+class SHARSettings(settings.Group):
+    class SHARRandomizerExe(settings.FilePath):
+        """
+        Path to SHARRandomizer.exe to auto-launch.
+        Example: "C:/Program Files (x86)/Vivendi Universal Games/The Simpsons Hit & Run/SHARRandomizer.exe"
+        """
+        description = "Path to SHARRandomizer.exe"
+
+    class LucasLauncherExe(settings.FilePath):
+        """
+        Path to Lucas' Mod Launcher.exe to auto-launch.
+        Can't auto launch straight into running the mod saldy.
+        Example: "C:/Program Files (x86)/Vivendi Universal Games/The Simpsons Hit & Run/Lucas Simpsons Hit & Run Mod Launcher.exe"
+        """
+        description = "Path to Lucas' Mod Launcher.exe"
+
+    sharrandomizer: SHARRandomizerExe = SHARRandomizerExe("")
+    lucas_launcher: LucasLauncherExe = LucasLauncherExe("")
+
 class SimpsonsHitAndRunWorld(World):
     """A 2003 Action Adventure game similar to the GTA series starring the Simpsons"""
     from BaseUtils import get_archipelago_json
@@ -46,10 +110,11 @@ class SimpsonsHitAndRunWorld(World):
     author: str = AUTHOR
     web = world_webworld
 
+    settings: typing.ClassVar[SHARSettings]
     options_dataclass = SimpsonsHitAndRunOptions
     data_version = WORLD_VERSION
     required_client_version = (0, 5, 0)
-    apworld_version = "0.3.3"
+    apworld_version = "0.4.3"
     # These properties are set from the imports of the same name above.
     item_table = item_table
     location_table = location_table # this is likely imported from Data instead of Locations because the Game Complete location should not be in here, but is used for lookups
@@ -69,17 +134,130 @@ class SimpsonsHitAndRunWorld(World):
     location_name_groups = location_name_groups
     victory_names = victory_names
 
-    def interpret_slot_data(self, slot_data: dict[str, any]):
-        #this is called by tools like UT
+    card_table = []
+    mission_locks = {}
+    progcars = []
+    vehicle_item_to_vehicle = {
+        "ambul": "Ambulance",
+        "apu_v": "Longhorn",
+        "atv_v": "ATV",
+        "bart_v": "Ferrini - Red",
+        "bbman_v": "El Carro Loco",
+        "bookb_v": "Book Burning Van",
+        "burns_v": "36 Stutz Bearcat",
+        "burnsarm": "Burns Armored Truck",
+        "carhom_v": "Car Built For Homer",
+        "cArmor": "Armored Truck",
+        "cBlbart": "Ferrini - Black",
+        "cBone": "Bonestorm Truck",
+        "cCellA": "Cell Phone Car",
+        "cCola": "Cola Truck",
+        "cCube": "Cube Van",
+        "cCurator": "Curator",
+        "cDonut": "Donut Truck",
+        "cDuff": "Duff Truck",
+        "cFire_v": "Fire Truck",
+        "cHears": "Hearse",
+        "cKlimo": "Krusty's Limo",
+        "cletu_v": "Pickup Truck",
+        "cLimo": "Limo",
+        "cMilk": "Milk Truck",
+        "cNerd": "Nerd Car",
+        "cNonup": "Nonuplets Minivan",
+        "coffin": "Coffin Car",
+        "comic_v": "Kremlin",
+        "compactA": "Compact Car",
+        "cSedan": "Chase Sedan",
+        "cVan": "Surveillance Van",
+        "dune_v": "R/C Buggy",
+        "elect_v": "Electaurus",
+        "famil_v": "Family Sedan",
+        "fishtruc": "Fish Van",
+        "fone_v": "Open Wheel Race Car",
+        "frink_v": "Hover Car",
+        "garbage": "Garbage Truck",
+        "glastruc": "Glass Truck",
+        "gramp_v": "WWII Vehicle",
+        "gramR_v": "WWII Vehicle W/ Rocket",
+        "hallo": "Hearse",
+        "hbike_v": "Hover Bike",
+        "homer_v": "70's Sports Car",
+        "honor_v": "Honor Roller",
+        "hype_v": "Planet Hype 50's Car",
+        "icecream": "Ice Cream Truck",
+        "IStruck": "Itchy and Scratchy Movie Truck",
+        "knigh_v": "Knight Boat",
+        "krust_v": "Clown Car",
+        "lisa_v": "Malibu Stacy Car",
+        "marge_v": "Canyonero",
+        "minivanA": "Minivan",
+        "moe_v": "Moe's Sedan",
+        "mono_v": "Monorail Car",
+        "mrplo_v": "Mr. Plow",
+        "nuctruck": "Nuclear Waste Truck",
+        "oblit_v": "Obliteratatron Big Wheel Truck",
+        "otto_v": "School Bus",
+        "pickupA": "Pickup",
+        "pizza": "Pizza Van",
+        "plowk_v": "Plow King",
+        "rocke_v": "Speed Rocket",
+        "schoolbu": "Mini School Bus",
+        "scorp_v": "Globex Super Villain Car",
+        "sedanA": "Sedan A",
+        "sedanB": "Sedan B",
+        "ship": "Ghost Ship",
+        "skinn_v": "Skinner's Sedan",
+        "smith_v": "Mr. Burns' Limo",
+        "snake_v": "Bandit",
+        "sportsA": "Sports Car A",
+        "sportsB": "Sports Car B",
+        "SUVA": "SUV",
+        "taxiA": "Taxi",
+        "votetruc": "Vote Quimby Truck",
+        "wagonA": "Station Wagon",
+        "wiggu_v": "Police Car",
+        "willi_v": "Tractor",
+        "witchcar": "Witch's Broom",
+        "zombi_v": "Zombie Car",
+        "tt": "Audi TT"
+    }
 
-        regen = False
-        for key, value in slot_data.items():
-            if key in self.options_dataclass.type_hints:
-                getattr(self.options, key).value = value
-                regen = True
+    ut_can_gen_without_yaml = True
+    @staticmethod
+    def interpret_slot_data(slot_data: Dict[str, Any]) -> Dict[str, Any]:
+        return slot_data
 
-        regen = hook_interpret_slot_data(self, self.player, slot_data) or regen
-        return regen
+    def generate_early(self) -> None:
+        if self.options.cardlogic == 2:
+            raise OptionError("Chosen cardlogic level is not implemented.")
+
+        if hasattr(self.multiworld, "re_gen_passthrough"):
+            if self.game in self.multiworld.re_gen_passthrough:
+                print("Getting UT slot data.")
+                passthrough = self.multiworld.re_gen_passthrough[self.game]
+
+                for key in vars(self.options):
+                    if key in passthrough:
+                        option = getattr(self.options, key)
+                        print(f"{key} : {option}")
+                        if hasattr(option, "value"):
+                            value = passthrough[key]
+                            option.value = value
+                            print(f"{key} : {option} : {value}")
+
+                self.mission_locks = passthrough["missionlockdic"]
+                self.progcars = passthrough["progcars"]
+
+
+        if "None" in self.options.earlyforward.value:
+            self.options.earlyforward.value = set()
+
+        elif "All" in self.options.earlyforward.value:
+            self.options.earlyforward.value = {"Homer", "Bart", "Lisa", "Marge", "Apu"}
+
+        for c in self.options.earlyforward.value:
+            if c in self.options.shuffleforward.value:
+                self.multiworld.local_early_items[self.player][f"{c} Forward"] = 1
 
     @classmethod
     def stage_assert_generate(cls, multiworld) -> None:
@@ -88,6 +266,49 @@ class SimpsonsHitAndRunWorld(World):
 
     def create_regions(self):
         before_create_regions(self, self.multiworld, self.player)
+        locbk = {}
+
+        if self.options.missionlocks != 0:
+            if not hasattr(self.multiworld, "generation_is_fake"):
+                carlocks = self.random.sample(
+                    list(self.vehicle_item_to_vehicle.keys()),
+                    int(49 * (self.options.missionlocks / 100))
+                )
+                missions = self.random.sample(range(1, 50), len(carlocks))
+                self.mission_locks = dict(zip(missions, carlocks))
+
+            level_bases = {
+                1: 122289,
+                2: 122300,
+                3: 122311,
+                4: 122322,
+                5: 122333,
+                6: 122344,
+                7: 122355,
+            }
+
+            for m, car in self.mission_locks.items():
+                m = int(m)
+                item = self.item_name_to_item[self.vehicle_item_to_vehicle[car]]
+                item.pop("useful", None)
+                if "Filler" in item.get("category", []):
+                    item["category"].remove("Filler")
+                item["progression"] = True
+                #self.multiworld.local_early_items[self.player][item["name"]] = 1
+
+                level = (m - 1) // 7 + 1
+                mission = (m - 1) % 7 + 1
+                id_number = level_bases[level] + (mission - 1)
+
+                loc = self.location_name_to_location[self.location_id_to_name[id_number]]
+                req = loc.get("requires", "")
+                locbk[loc["name"]] = req
+                if not req:
+                    loc["requires"] = f"|{item['name']}|"
+                else:
+                    loc["requires"] = f"{req} AND |{item['name']}|"
+        else:
+            self.mission_locks = {0 : "NO MISSIONLOCKS"}
 
         create_regions(self, self.multiworld, self.player)
 
@@ -100,9 +321,15 @@ class SimpsonsHitAndRunWorld(World):
         location_game_complete.place_locked_item(
             SimpsonsHitAndRunItem("__Victory__", ItemClassification.progression, None, player=self.player))
 
-        cards_data = json.loads(pkgutil.get_data(__name__, "data/cards.json").decode())
+        data_path = Path("data") / "cards.json"
+        cards_data = json.loads(pkgutil.get_data(__name__, str(data_path)).decode())
+        self.card_table = []
 
-        after_create_regions(self, self.multiworld, self.player, cards_data)
+        for l, r in locbk.items():
+            loc = self.location_name_to_location[l]
+            loc["requires"] = r
+
+        after_create_regions(self, self.multiworld, self.player, cards_data, self.card_table)
 
     def create_items(self):
         # Generate item pool
@@ -117,6 +344,24 @@ class SimpsonsHitAndRunWorld(World):
             "Hit N Run": "hnr"
         }
 
+        cars_by_level = {}
+        for item in item_name_to_item.values():
+            for category in item.get("category", []):
+                match = re.match(r"Level ([1-7]) Car", category)
+                if match and not item.get("progression", False):
+                    level = int(match.group(1))
+                    cars_by_level.setdefault(level, []).append(item)
+
+        if not hasattr(self.multiworld, "generation_is_fake"):
+            for car in [self.random.choice(cars) for cars in cars_by_level.values()]:
+                car.pop("useful", None)
+                car["progression"] = True
+                self.progcars.append(car)
+        else:
+            for car in self.progcars:
+                car.pop("useful", None)
+                car["progression"] = True
+
         for name in configured_item_names.values():
             item = self.item_name_to_item[name]
             item_count = int(item.get("count", 1))
@@ -130,7 +375,6 @@ class SimpsonsHitAndRunWorld(World):
 
             if item_count == 0: continue
 
-
             for i in range(item_count):
                 new_item = self.create_item(name)
                 pool.append(new_item)
@@ -141,43 +385,12 @@ class SimpsonsHitAndRunWorld(World):
                 if name not in self.multiworld.local_items[self.player].value:
                     self.options.local_items.value.add(name)
 
+
         pool = before_create_items_starting(pool, self, self.multiworld, self.player)
 
         items_started = []
 
-        #if starting_items: #probably unnecessary
-        if False:
-            for starting_item_block in starting_items:
-                # if there's a condition on having a previous item, check for any of them
-                # if not found in items started, this starting item rule shouldn't execute, and check the next one
-                if "if_previous_item" in starting_item_block:
-                    matching_items = [item for item in items_started if item.name in starting_item_block["if_previous_item"]]
 
-                    if len(matching_items) == 0:
-                        continue
-
-                # start with the full pool of items
-                items = pool
-
-                # if the setting lists specific item names, limit the items to just those
-                if "items" in starting_item_block:
-                    items = [item for item in pool if item.name in starting_item_block["items"]]
-
-                # if the setting lists specific item categories, limit the items to ones that have any of those categories
-                if "item_categories" in starting_item_block:
-                    items_in_categories = [item["name"] for item in self.item_name_to_item.values() if "category" in item and len(set(starting_item_block["item_categories"]).intersection(item["category"])) > 0]
-                    items = [item for item in pool if item.name in items_in_categories]
-
-                self.random.shuffle(items)
-
-                # if the setting lists a specific number of random items that should be pulled, only use a subset equal to that number
-                if "random" in starting_item_block:
-                    items = items[0:starting_item_block["random"]]
-
-                for starting_item in items:
-                    items_started.append(starting_item)
-                    self.multiworld.push_precollected(starting_item)
-                    pool.remove(starting_item)
 
         self.start_inventory = {i.name: items_started.count(i) for i in items_started}
 
@@ -331,19 +544,92 @@ class SimpsonsHitAndRunWorld(World):
                 continue
             slot_data[option_key] = get_option_value(self.multiworld, self.player, option_key)
 
-        slot_data["card_locations"] = [card["id"] for card in card_table]
+        slot_data["card_locations"] = [card["id"] for card in self.card_table]
+        slot_data["missionlockdic"] = self.mission_locks
+        slot_data["progcars"] = self.progcars
+        slot_data["VerifyID"] = f"AP-{self.multiworld.seed_name}-P{self.player}-{self.multiworld.get_file_safe_player_name(self.player)}"
+
+        slot_data["ingamehints"] = self.get_ingame_hints() if self.options.extrahintpolicy else "No hints"
 
         slot_data = after_fill_slot_data(slot_data, self, self.multiworld, self.player)
 
         return slot_data
 
+    def get_ingame_hints(self):
+        igh = {}
+
+        for item in self.progcars:
+            try:
+                loc = self.multiworld.find_item(item["name"], self.player)
+
+            except StopIteration:
+                pass
+
+            igh[item["id"]] = (loc.address, loc.player)
+
+        for _, item in self.mission_locks.items():
+            if item == "NO MISSIONLOCKS":
+                continue
+
+            itemName = self.vehicle_item_to_vehicle[item]
+            item = item_name_to_item[itemName]
+            try:
+                loc = self.multiworld.find_item(item["name"], self.player)
+
+            except StopIteration:
+                pass
+
+            igh[item["id"]] = (loc.address, loc.player)
+
+        return igh
+
     def generate_output(self, output_directory: str):
-        filename = f"{self.multiworld.get_out_file_name_base(self.player)}_SHAR.json"
-        gen(output_directory, filename, card_table, self.player)
+        filename = f"{self.multiworld.get_out_file_name_base(self.player)}_SHAR"
+
+        traffic_table = (
+            self.random.sample(list(self.vehicle_item_to_vehicle.keys()), 35)
+            if self.options.shuffletraffic
+            else ["NO TRAFFIC"]
+        )
+
+        gen(
+            output_directory,
+            filename,
+            f"AP-{self.multiworld.seed_name}-P{self.player}-{self.multiworld.get_file_safe_player_name(self.player)}",
+            f"AP-{self.multiworld.seed_name}-P{self.player}",
+            self.card_table,
+            traffic_table,
+            self.mission_locks,
+            self.player
+        )
 
     def write_spoiler(self, spoiler_handle):
         before_write_spoiler(self, self.multiworld, spoiler_handle)
 
+        if self.options.missionlocks:
+            level_bases = {
+                1: 122289,
+                2: 122300,
+                3: 122311,
+                4: 122322,
+                5: 122333,
+                6: 122344,
+                7: 122355,
+            }
+            spoiler_handle.write(f"\n{self.multiworld.get_file_safe_player_name(self.player)} Mission Locks\n")
+            for m, car in self.mission_locks.items():
+                item = self.item_name_to_item[self.vehicle_item_to_vehicle[car]]
+
+                level = (m - 1) // 7 + 1
+                mission = (m - 1) % 7 + 1
+                id_number = level_bases[level] + (mission - 1)
+
+                loc = self.location_name_to_location[self.location_id_to_name[id_number]]
+
+                loc_name = loc["name"]
+                item_name = item["name"]
+                spoiler_handle.write(f"{m}: {loc_name} requires {item_name}\n")
+
     ###
     # Non-standard AP world methods
     ###
@@ -368,7 +654,7 @@ class SimpsonsHitAndRunWorld(World):
                 item_pool.append(extra_item)
 
             for _ in range(0, filler_count):
-                extra_item = self.create_item("Wrench")
+                extra_item = self.create_item("10 Coins")
                 item_pool.append(extra_item)
         elif extras < 0:
             logging.warning(f"{self.game} has more items than locations. {abs(extras)} non-progression items will be removed at random.")
@@ -390,7 +676,6 @@ class SimpsonsHitAndRunWorld(World):
                     logging.warning("Could not remove enough non-progression items from the pool.")
                     break
                 item_pool.remove(popped)
-
         return item_pool
 
     def get_item_counts(self, player: Optional[int] = None, reset: bool = False) -> dict[str, int]:
